%fibonacci
% Generates the first N terms of the Fibonacci sequence.
%
% LAST UPDATED by Andy French April 2016

function fibonacci

%Display message to command window
disp(' ');
disp(' %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%' )
disp('  Fibonacci Sequence Generator ' )
disp(' %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%' )
disp(' ')

%Ask user form number of terms
% Set default of 20 if nothing is stated and the return key is pressed.
N = input(' How many terms of the sequence? N = ');
if isempty(N)
    N = 20;
    disp(' Default of N = 20 chosen.')
end

%Initialize vector F, in which we will store the Fibonacci numbers.
%This is much faster than letting F grow with the loop.
%Note by convention, F(1) = 1 and F(2) = 1.
F = ones(1,N);

%Initialize ratio R of F(n)/F(n-1). Define R(1) = 1 and R(2) = 1.
R = ones(1,N);

%Loop through sequence
if N>=3
    for n=3:N
        F(n) = F(n-1) + F(n-2);
        R(n) = F(n)/F(n-1);
    end
end

%Display results to command window
disp(' ');
for n=1:N
    disp([' n = ',num2str(n),...
        ', F(',num2str(n),') = ',num2str(F(n)),...
        ', R(',num2str(n),') = ',num2str(R(n))] );
end
disp(' ');

%Plot results
fsize = 18;
figure('color',[1 1 1],'name','sequences');
plot(1:N,R);
hold on;
plot(1:N,R,'o');
plot(0:N,ones(1,N+1)*(1 + sqrt(5))/2,'r-')
xlabel('Term number n','fontsize',fsize)
ylabel('Ratio F(n)/F(n-1)','fontsize',fsize)
title({['Fibonacci sequence F(n). N=',num2str(N),' terms.'],...
    ['Golden Ratio (1 + sqrt(5))/2 = ',num2str((1 + sqrt(5))/2)]},...
    'fontsize',fsize)
set(gca,'fontsize',fsize)
grid on

%Save a .png file of the plot
print( gcf, ['fibonacci N=',num2str(N),'.png'], '-dpng','-r300' );

%End of code