%randomwalk
% Uses a for loop to determine the random path of a particle.
% Note a vectorized version of this code would offer a massive speed boost when the
% number of steps becomes large. In this simulation, the step size and the
% step direction are uniform random variables. The step size is from 0 to
% smax, which is specified my the user.
%
% LAST UPDATED by Andy French. April 2016

function randomwalk

%Set fontsize for plot
fsize = 18;

%Display message to command window
disp(' ')
disp('%%%%%%%%%%%%%%%%%%%%%%%%')
disp(' Random walk simulation ' )
disp('%%%%%%%%%%%%%%%%%%%%%%%%')
disp(' ')

%Get maximum step size. Default is 1.
disp(' Define maximum step size...')
smax = input(' > ');
if isempty(smax)
    smax = 1;
    disp(' Default maximum step size set at 1')
end
disp(' ');

%Get number of steps
disp(' Define number of steps...')
N = input(' > ');
if isempty(N)
    N = 10000;
    disp(' Default maximum step size set at 10,000')
end

%Initialize step coordinates as N length vectors
x = zeros(1,N);
y = zeros(1,N);

%Loop through steps, updating x and y accordingly.
if N>=2
    for n=2:N
        theta = 2*pi*rand;
        r = rand*smax;
        x(n) = x(n-1) + r*cos(theta);
        y(n) = y(n-1) + r*sin(theta);
    end
end

%Plot trajectory, and save it as a .png file
%Plot start and finish with green and red stars.
figure('color',[1 1 1],'name','randomwalk');
plot(x,y);
hold on;
plot(0,0,'g*');
plot(x(end),y(end),'r*');
grid on
set(gca,'fontsize',fsize)
xlabel('x','fontsize',fsize)
ylabel('y','fontsize',fsize)
title(['Random walk. Max step size = ',num2str(smax),...
    ', N = ',num2str(N)],'fontsize',fsize)
filename = ['randomwalk ',strrep(datestr(now),':','-'),'.png'];
print( gcf, filename, '-dpng','-r300' );

%End of code