%sequences
% Function which uses a for loop to sum a sequnce defined by iterative
% formula y = f(x,n). x is the nth term of the sequence, y is the n+1 th
% term.
%
% LAST UPDATED by Andy French April 2016.

function sequences

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Inputs %%

%Set first term of the sequence
a = 1;

%Define number of terms
N = 20;

%Fontsize for graphs
fsize = 18;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Initialise term u and sequence cumlative sum s vectors
u = ones(1,N);
s = ones(1,N);
u(1) = a;
s(1) = a;

%Initialize term and sum variables
x = a;
S = a;

%Loop iteration
if N>=2
    for n=2:N
        %Compute next term
        x = f(x,n);
        
        %Add to cumulative sum of sequence terms
        S = S + x;
        
        %Store terms in vectors
        u(n) = x;
        s(n) = S;
    end
end

%Display results to command window
disp(' ');
for n=1:N
    disp([' n = ',num2str(n),...
        ', u(',num2str(n),') = ',num2str(u(n)),...
        ', s(',num2str(n),') = ',num2str(s(n))] );
end
disp(' ');

%Plot results
figure('color',[1 1 1],'name','sequences');
plot(1:N,u,1:N,s);
hold on;
plot(1:N,u,'o',1:N,s,'o');
xlabel('Term number','fontsize',fsize)
ylabel('Term or sum','fontsize',fsize)
title('Iterative sequence','fontsize',fsize)
set(gca,'fontsize',fsize)
legend({'Term','Sum'},'fontsize',fsize,'location','best')
grid on

%Save a .png file of the plot
filename = ['sequences ',strrep(datestr(now),':','-'),'.png'];
print( gcf, filename, '-dpng','-r300' );

%%

%Iteration formula involving the nth term x or a sequence, the term number
%n and the n+1 th term y.
function y = f(x,n)

% %Arithmetic sequence
% d = 1;
% y = x + d;

% %Geometric sequence
% r = 0.9;
% y = r*x;

%Alternating geometric sequence
r = 0.9;
y = r*x*( (-1)^n );

%End of code