%sptriangle
% Generation of the Seirpinski Triangle fractal using the "Chaos Game"
% algorithm by Michael Barnsley.
%
% LAST UPDATED by Andy French. April 2016.

function sptriangle

%Set fontsize for plot
fsize = 18;

%Markersize for plot
msize = 2;

%Initialize starting location (it actually doesn't matter where this is!)
x = 0;
y = 0;

%Define location of triangle vertices. Let sides of triangle = 1 unit

%Red vertex
Rx=-0.5; Ry=-0.5/sqrt(3);

%Green vertex
Gx=0; Gy=1/sqrt(3) ;

%Blue vertex
Bx=0.5; By=-0.5/sqrt(3) ;

%

%Display message to command window
disp(' ')
disp('%%%%%%%%%%%%%%%%%%%%%%%%')
disp(' Sierpinski Triangle ' )
disp('%%%%%%%%%%%%%%%%%%%%%%%%')
disp(' ')

%Get number of steps
disp(' Define number of steps...')
N = input(' > ');
if isempty(N)
    N = 10000;
    disp(' Default maximum step size set at 10,000')
end
disp(' ');

%Define odds ratio for Red, Green and Blue vertices of the triangle
disp(' Define Red ratio')
R = input(' > ');
if isempty(R)
    R = 1;
    disp(' Default Red ratio is 1')
end
disp(' ');
disp(' Define Green ratio')
G = input(' > ');
if isempty(G)
    G = 1;
    disp(' Default Green ratio is 1')
end
disp(' ');
disp(' Define Blue ratio')
B = input(' > ');
if isempty(B)
    B = 1;
    disp(' Default Blue ratio is 1')
end
disp(' ');

%Start timer, and begin to generate the triangle
disp(' Generating Sierpinski triangle ...')
t0 = tic;

%Initialize plot coordinate vectors for Red Green and Blue colours. 
xred = []; yred = [];
xgreen = []; ygreen = [];
xblue = []; yblue = [];

%Set probabilities for R,G,B
P = [R,G,B]/(R+G+B);

%Generate N random numbers between 0 and 1
r=rand(1,N) ;

%Step through random number vector and thus determine 'Sierpinski
%trajectory'. Add to red, green, or blue coordinate vectors as they are
%chosen
if N>=2
    for n=1:N
        if r(n) < P(1)
            %Pick red vertex
            x = x + 0.5 *( Rx - x );
            y = y + 0.5 *( Ry - y );  
            xred = [xred,x];
            yred = [yred,y];
        elseif ( r(n) < ( P(1)+P(2) ) ) && ( r(n) >=P(1) )
            %Pick green vertex
            x = x + 0.5 *( Gx - x );
            y = y + 0.5 *( Gy - y );
            xgreen = [xgreen,x];
            ygreen = [ygreen,y];         
        elseif  r(n) > ( P(1) + P(2) )
            %Pick blue vertex
            x = x + 0.5 *( Bx - x );
            y = y + 0.5 *( By - y );
            xblue = [xblue,x];
            yblue = [yblue,y];
        end
    end
end

%Generate figure, plot verticies and plot trajectories via colour
figure('color',[1,1,1],'name','Sierpinski Triangle') ;

%Plot first point and triangle vertices
plot( Rx, Ry, 'r*' ); hold on;
plot( Gx, Gy, 'g*' );
plot( Bx, By, 'b*' );

%Plot red, green and blue plot points
plot(xred,yred,'r.',xgreen,ygreen,'g.',xblue,yblue,'b.','markersize',msize);

%Set axes labels etc
title( {'Sierpinski triangle via chaos game.',...
    ['N = ',num2str(N),', odds = ',num2str(R),':',num2str(G),':',num2str(B)] },'fontsize',fsize);
set( gca, 'xtick', -0.6 : 0.2 : 0.6 , 'ytick', -0.6 : 0.2 : 0.6 );
axis equal
xlabel('x','fontsize',fsize)
ylabel('y','fontsize',fsize)
set(gca,'fontsize',fsize)
grid on
box on

%Plot graph
print(gcf,['sierpinski N=',num2str(N),...
    ' odds=',num2str(R),'-',num2str(G),'-',num2str(B),'.png'],'-dpng','-r300' );

%Display completion message
disp([' Sierpinski triangle generated in ',num2str(toc(t0)),' seconds.'])
disp(' ')

%End of code
